@@ -38,14 +38,11 @@ class SSHDAnalysisTask(TurbiniaTask):
     Returns:
         TurbiniaTaskResult object.
     """
-    # What type of evidence we should output.
-    output_evidence = ReportText()
-
     # Where to store the resulting output file.
     output_file_name = 'sshd_config_analysis.txt'
     output_file_path = os.path.join(self.output_dir, output_file_name)
     # Set the output file as the data source for the output evidence.
-    output_evidence.local_path = output_file_path
+    output_evidence = ReportText(source_path=output_file_path)
 
     # Read the input file
     with open(evidence.local_path, 'r') as input_file:
@@ -57,7 +54,7 @@ class SSHDAnalysisTask(TurbiniaTask):
     result.report_data = report
 
     # Write the report to the output file.
-    with open(output_file_path, 'w') as fh:
+    with open(output_file_path, 'wb') as fh:
       fh.write(output_evidence.text_data.encode('utf-8'))
 
     # Add the resulting evidence to the result object.
@@ -83,14 +80,14 @@ class SSHDAnalysisTask(TurbiniaTask):
         r'^\s*PermitRootLogin\s*(yes|prohibit-password|without-password)',
         re.IGNORECASE | re.MULTILINE)
     password_authentication_re = re.compile(
-        r'^\s*PasswordAuthentication[\s"]*No', re.IGNORECASE | re.MULTILINE)
+        r'^\s*PasswordAuthentication[\s"]*yes', re.IGNORECASE | re.MULTILINE)
     permit_empty_passwords_re = re.compile(
         r'^\s*PermitEmptyPasswords[\s"]*Yes', re.IGNORECASE | re.MULTILINE)
 
     if re.search(permit_root_login_re, config):
       findings.append(fmt.bullet('Root login enabled.'))
 
-    if not re.search(password_authentication_re, config):
+    if re.search(password_authentication_re, config):
       findings.append(fmt.bullet('Password authentication enabled.'))
 
     if re.search(permit_empty_passwords_re, config):
